/*
Copyright (c) 2006-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/

#ifndef __CONTROLFRAMEWORKVIEW_H
#define __CONTROLFRAMEWORKVIEW_H

#include <coecntrl.h>
#include <coeview.h>
#include <babitflags.h> 

class CControlFrameworkAppUi;

//View class
class CControlFrameworkView : public CCoeControl, public MCoeView
	{
public:
	static CControlFrameworkView* NewLC(CControlFrameworkAppUi& iAppUi);
	~CControlFrameworkView();
	
	TBool IsBold() const;
	TBool IsItalic() const;
	TBool IsUnderline() const;
	TBool IsStrikethrough() const;
	void ToggleBold();
	void ToggleItalic();
	void ToggleUnderline();
	void ToggleStrikethrough();

	// from MCoeView
	TVwsViewId ViewId() const;
    
protected:
	CControlFrameworkView(CControlFrameworkAppUi& iAppUi);
	void DrawBorder(TRect& aRect) const;
	void DrawMessage(const TRect& aRect) const;

	// from MCoeView
	void ViewConstructL();
	void ViewActivatedL(const TVwsViewId &aPrevViewId, TUid aCustomMessageId, const TDesC8 &aCustomMessage);
	void ViewDeactivated();
    
	// from CCoeControl
	TKeyResponse OfferKeyEventL(const TKeyEvent& aKeyEvent,TEventCode aType);
	void HandlePointerEventL(const TPointerEvent& aPointerEvent);
	void Draw( const TRect& /*aRect*/ ) const;
    
private:
	CControlFrameworkAppUi& iAppUi;
	TBidiText* iBidiText;

	RRunInfoArray iRunInfoArray;
	TCoeFont iFont;
    
	enum TCommandBools
		{
		EBold,
		EItalic,
		EUnderline,
		EStrikethrough
		};
	TBitFlags iFontFlags;
	};



#endif // __CONTROLFRAMEWORKVIEW_H

