/*
Copyright (c) 2006-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/


#include "ControlFrameworkAppUi.h"
#include "ControlFrameworkView.h"
#include "ControlFramework.hrh"
#include "uikon.hrh"


CControlFrameworkAppUi::CControlFrameworkAppUi()
	{
	}

CControlFrameworkAppUi::~CControlFrameworkAppUi()
	{
	// Deregister the view(s) from the view server, remove the view(s) from the control stack
	// and delete them
	TInt view = iAppViews.Count();
	while (view--)
		{
		CControlFrameworkView* v = iAppViews[view];
		RemoveFromStack(v);
		DeregisterView(*v);
		}
	iAppViews.ResetAndDestroy();
	}

// Second phase constructor of the application UI.
// It creates and owns a single view. The view is not fully constructed 
// (via ViewConstructL()) until the first time the view is activated,
// to improve application startup time.
void CControlFrameworkAppUi::ConstructL()
	{
	BaseConstructL(CEikAppUi::EStandardApp);
	
   	// Create the view
	CControlFrameworkView* view = CControlFrameworkView::NewLC(*this);
	AddViewL(view);
	CleanupStack::Pop(view);
	}


// Called by the UI framework when a command has been issued 
// by one of the toolbar buttons.
void CControlFrameworkAppUi::HandleCommandL(TInt aCommandId)
	{
	CControlFrameworkView& view = *iAppViews[EExampleView];
	switch (aCommandId)
		{
		// command IDs are defined in the hrh file.
		case ECmdToggleBoldFont:
			view.ToggleBold();
			break;
		
		case ECmdToggleItalicFont:	
			view.ToggleItalic();
			break;
		
		case ECmdToggleUnderline: 
			view.ToggleUnderline();
			break;
			
		case ECmdToggleStrikethrough: 
			view.ToggleStrikethrough();
			break;
				
		default:				
		case EEikCmdExit:
			Exit();
		}
	}


static void CleanupRemoveFromStack(TAny* aView)
	{ 
	static_cast<CEikAppUi*>(CCoeEnv::Static()->AppUi())->RemoveFromStack(static_cast<CControlFrameworkView*>(aView)); 
	}

static void CleanupDeregisterView(TAny* aView) 
	{ 
	static_cast<CEikAppUi*>(CCoeEnv::Static()->AppUi())->DeregisterView(*static_cast<CControlFrameworkView*>(aView)); 
	}

// Adds the view to the app UI's control stack and registers it with the view server. 
// Takes ownership of the view.
void CControlFrameworkAppUi::AddViewL(CControlFrameworkView* aView)
	{
	ASSERT(aView);
	ASSERT(KErrNotFound == iAppViews.Find(aView));
		
	RegisterViewL(*aView); // Call RegisterViewL before AddToStackL to avoid panic in destructor if AddToStackL leaves 
	CleanupStack::PushL(TCleanupItem(CleanupDeregisterView,aView)); 
	
	AddToStackL(*aView, aView); 
	CleanupStack::PushL(TCleanupItem(CleanupRemoveFromStack, aView)); 
	
	iAppViews.AppendL(aView); 
	CleanupStack::Pop(2); 
	}
